import { APIClient, APIFetchOptions, BrowserStackOptions } from './api-client.ts';
import { components, operations } from './generated/openapi.ts';
/**
 * AppAutomateClient represents a client for interacting with the BrowserStack App Automate API.
 * @see https://www.browserstack.com/app-automate/rest-api
 * @public
 */
export declare class AppAutomateClient extends APIClient {
    /**
     * Constructs a new instance of the AppAutomateClient class.
     * @param options - Optional configuration options for the client.
     */
    constructor(options?: BrowserStackOptions);
    /**
     * Retrieves the plan information for App Automate.
     * @param options - The fetch options for the request.
     * @returns A promise that resolves with the plan information.
     */
    getPlan(options?: APIFetchOptions<operations["getAppAutomatePlan"]>): Promise<{
        automate_plan: string;
        parallel_sessions_running: number;
        parallel_sessions_max_allowed: number;
        team_parallel_sessions_max_allowed: number;
        queued_sessions: number;
        queued_sessions_max_allowed: number;
    }>;
    /**
     * Retrieves the list of devices available for App Automate.
     * @param options - The fetch options for the request.
     * @returns A promise that resolves with the list of devices.
     */
    getDevices(options?: APIFetchOptions<operations["getAppAutomateDevices"]>): Promise<{
        os: string;
        os_version: string;
        device: string;
        real_mobile: boolean;
    }[]>;
    /**
     * Retrieves the projects from the App Automate API.
     * @param options - The fetch options for the API request.
     * @returns A promise that resolves with the projects.
     */
    getProjects(options?: APIFetchOptions<operations["getAppAutomateProjects"]>): Promise<{
        id: number;
        name: string;
        user_id: number;
        group_id: number;
        sub_group_id: number;
        created_at: string;
        updated_at: string;
    }[]>;
    /**
     * Retrieves a project by its ID.
     * @param projectId The ID of the project to retrieve.
     * @param options Additional options for the fetch request.
     * @returns A promise that resolves to the retrieved project.
     */
    getProject(projectId: number, options?: APIFetchOptions<operations["getAppAutomateProject"]>): Promise<{
        id: number;
        name: string;
        user_id: number;
        group_id: number;
        sub_group_id: number;
        created_at: string;
        updated_at: string;
    } & {
        builds: {
            name: string;
            duration: number;
            status: "running" | "timeout" | "failed" | "done";
            user_id?: number | undefined;
            group_id?: number | undefined;
            sub_group_id?: number | undefined;
            automation_project_id?: number | undefined;
            hashed_id: string;
            build_tag: string;
            delta?: boolean | undefined;
            framework?: string | undefined;
            test_data?: Record<string, never> | undefined;
            created_at?: string | undefined;
            updated_at?: string | undefined;
        }[];
    }>;
    /**
     * Updates a project in the App Automate API.
     *
     * @param projectId - The ID of the project to update.
     * @param body - The request body containing the updated project data.
     * @param options - Additional options for the request.
     * @returns A promise that resolves with the updated project data.
     */
    updateProject(projectId: number, body: operations["updateAppAutomateProject"]["requestBody"]["content"]["application/json"], options?: APIFetchOptions<operations["updateAppAutomateProject"]>): Promise<{
        id: number;
        name: string;
        user_id: number;
        group_id: number;
        sub_group_id: number;
        created_at: string;
        updated_at: string;
    }>;
    /**
     * Deletes a project.
     * @param projectId The ID of the project to delete.
     * @param options The fetch options for the delete request.
     * @returns A promise that resolves when the project is successfully deleted.
     */
    deleteProject(projectId: number, options?: APIFetchOptions<operations["deleteAppAutomateProject"]>): Promise<{
        status?: string | undefined;
        message?: string | undefined;
    }>;
    /**
     * Retrieves the badge key for a specific project.
     * @param projectId The ID of the project.
     * @param options Additional options for the fetch request.
     * @returns A promise that resolves to the badge key.
     */
    getBadgeKey(projectId: number, options?: APIFetchOptions<operations["getAppAutomateProjectBadgeKey"]>): Promise<string>;
    /**
     * Retrieves a list of builds from the App Automate API.
     *
     * @param query - Optional query parameters for filtering the builds.
     * @param options - Optional fetch options for the API request.
     * @returns A promise that resolves to an array of automation builds.
     */
    getBuilds(query?: operations["getAppAutomateBuilds"]["parameters"]["query"], options?: APIFetchOptions<operations["getAppAutomateBuilds"]>): Promise<{
        name: string;
        duration: number;
        status: "running" | "timeout" | "failed" | "done";
        user_id?: number | undefined;
        group_id?: number | undefined;
        sub_group_id?: number | undefined;
        automation_project_id?: number | undefined;
        hashed_id: string;
        build_tag: string;
        delta?: boolean | undefined;
        framework?: string | undefined;
        test_data?: Record<string, never> | undefined;
        created_at?: string | undefined;
        updated_at?: string | undefined;
    }[]>;
    /**
     * Retrieves information about a specific build.
     * @param buildId - The ID of the build to retrieve.
     * @param options - Additional options for the fetch request.
     * @returns A promise that resolves to the build information, including the build details and associated sessions.
     */
    getBuild(buildId: string, options?: APIFetchOptions<operations["getAppAutomateBuild"]>): Promise<{
        sessions: ({
            browser: string;
            browser_version: string;
        } & {
            os: string;
            os_version: string;
            device: string;
            real_mobile: boolean;
        } & {
            hashed_id: string;
            name: string;
            duration: number;
            status: "running" | "timeout" | "failed" | "done";
            browserstack_status: string;
            reason: string;
            build_name: string;
            project_name: string;
            logs: string;
            browser_url: string;
            public_url: string;
            appium_logs_url: string;
            video_url: string;
            browser_console_logs_url: string;
            har_logs_url: string;
            selenium_logs_url: string;
            selenium_telemetry_logs_url: string;
            created_at: string;
        })[];
        name: string;
        duration: number;
        status: "running" | "timeout" | "failed" | "done";
        user_id?: number | undefined;
        group_id?: number | undefined;
        sub_group_id?: number | undefined;
        automation_project_id?: number | undefined;
        hashed_id: string;
        build_tag: string;
        delta?: boolean | undefined;
        framework?: string | undefined;
        test_data?: Record<string, never> | undefined;
        created_at?: string | undefined;
        updated_at?: string | undefined;
    }>;
    /**
     * Updates a build in the App Automate API.
     *
     * @param buildId - The ID of the build to update.
     * @param body - The request body containing the updated build information.
     * @param options - Additional options for the request.
     * @returns A Promise that resolves to the updated build.
     * @throws {BrowserStackError} If an error occurs during the update.
     */
    updateBuild(buildId: string, body: operations["updateAppAutomateBuild"]["requestBody"]["content"]["application/json"], options?: APIFetchOptions<operations["updateAppAutomateBuild"]>): Promise<{
        name: string;
        duration: number;
        status: "running" | "timeout" | "failed" | "done";
        user_id?: number | undefined;
        group_id?: number | undefined;
        sub_group_id?: number | undefined;
        automation_project_id?: number | undefined;
        hashed_id: string;
        build_tag: string;
        delta?: boolean | undefined;
        framework?: string | undefined;
        test_data?: Record<string, never> | undefined;
        created_at?: string | undefined;
        updated_at?: string | undefined;
    }>;
    /**
     * Deletes a build with the specified ID.
     * @param buildId The ID of the build to delete.
     * @param options Additional options for the delete request.
     * @returns A promise that resolves when the build is successfully deleted.
     */
    deleteBuild(buildId: string, options?: APIFetchOptions<operations["deleteAppAutomateBuild"]>): Promise<{
        status?: string | undefined;
        message?: string | undefined;
    }>;
    /**
     * Uploads terminal logs for a specific build.
     * @param buildId - The ID of the build.
     * @param body - The request body containing the logs file and its filename.
     * @param options - Additional options for the request.
     * @returns A promise that resolves to the response of the request.
     */
    uploadBuildTerminalLogs(buildId: string, body: operations["uploadAppAutomateBuildTerminalLogs"]["requestBody"]["content"]["multipart/form-data"] & {
        filename: string;
    }, options?: APIFetchOptions<operations["uploadAppAutomateBuildTerminalLogs"]>): Promise<{
        message: string;
    }>;
    /**
     * Uploads terminal logs for a session.
     * @param sessionId - The ID of the session.
     * @param body - The request body containing the logs file and filename.
     * @param options - Additional options for the request.
     * @returns A promise that resolves to the response of the request.
     */
    uploadSessionTerminalLogs(sessionId: string, body: operations["uploadAppAutomateSessionTerminalLogs"]["requestBody"]["content"]["multipart/form-data"] & {
        filename: string;
    }, options?: APIFetchOptions<operations["uploadAppAutomateSessionTerminalLogs"]>): Promise<{
        message: string;
    }>;
    /**
     * Retrieves the session details for a given session ID.
     * @param sessionId - The ID of the session to retrieve.
     * @param options - Additional options for the fetch request.
     * @returns A promise that resolves to the automation session data.
     */
    getSession(sessionId: string, options?: APIFetchOptions<operations["getAppAutomateSession"]>): Promise<{
        browser: string;
        browser_version: string;
    } & {
        os: string;
        os_version: string;
        device: string;
        real_mobile: boolean;
    } & {
        hashed_id: string;
        name: string;
        duration: number;
        status: "running" | "timeout" | "failed" | "done";
        browserstack_status: string;
        reason: string;
        build_name: string;
        project_name: string;
        logs: string;
        browser_url: string;
        public_url: string;
        appium_logs_url: string;
        video_url: string;
        browser_console_logs_url: string;
        har_logs_url: string;
        selenium_logs_url: string;
        selenium_telemetry_logs_url: string;
        created_at: string;
    } & {
        app_details: {
            app_name?: string | undefined;
            app_version?: string | undefined;
            app_url?: string | undefined;
            app_custom_id?: string | undefined;
            uploaded_at?: string | undefined;
        };
    }>;
    /**
     * Updates the status of a session in the App Automate API.
     *
     * @param sessionId - The ID of the session to update.
     * @param body - The request body containing the updated session status.
     * @param options - Additional options for the API request.
     * @returns A Promise that resolves to the updated automation session.
     */
    updateSessionStatus(sessionId: string, body: operations["updateAppAutomateSession"]["requestBody"]["content"]["application/json"], options?: APIFetchOptions<operations["updateAppAutomateSession"]>): Promise<{
        browser: string;
        browser_version: string;
    } & {
        os: string;
        os_version: string;
        device: string;
        real_mobile: boolean;
    } & {
        hashed_id: string;
        name: string;
        duration: number;
        status: "running" | "timeout" | "failed" | "done";
        browserstack_status: string;
        reason: string;
        build_name: string;
        project_name: string;
        logs: string;
        browser_url: string;
        public_url: string;
        appium_logs_url: string;
        video_url: string;
        browser_console_logs_url: string;
        har_logs_url: string;
        selenium_logs_url: string;
        selenium_telemetry_logs_url: string;
        created_at: string;
    } & {
        app_details: {
            app_name?: string | undefined;
            app_version?: string | undefined;
            app_url?: string | undefined;
            app_custom_id?: string | undefined;
            uploaded_at?: string | undefined;
        };
    }>;
    /**
     * Deletes a session in the App Automate API.
     * @param sessionId - The ID of the session to delete.
     * @param options - Additional options for the delete request.
     * @returns A promise that resolves when the session is successfully deleted.
     */
    deleteSession(sessionId: string, options?: APIFetchOptions<operations["deleteAppAutomateSession"]>): Promise<{
        status?: string | undefined;
        message?: string | undefined;
    }>;
    /**
     * Retrieves the session logs for a specific build and session.
     *
     * @param buildId - The ID of the build.
     * @param sessionId - The ID of the session.
     * @param options - Additional options for the request.
     * @returns A Promise that resolves to the session logs.
     */
    getSessionLogs(buildId: string, sessionId: string, options?: APIFetchOptions<operations["getAppAutomateSessionLogs"]>): Promise<string>;
    /**
     * Retrieves the device logs for a specific session.
     *
     * @param buildId - The ID of the build.
     * @param sessionId - The ID of the session.
     * @param options - Additional options for the request.
     * @returns A Promise that resolves with the device logs.
     */
    getSessionDeviceLogs(buildId: string, sessionId: string, options?: APIFetchOptions<operations["getAppAutomateDeviceLogs"]>): Promise<string>;
    /**
     * Retrieves the Appium logs for a specific session.
     *
     * @param buildId - The ID of the build.
     * @param sessionId - The ID of the session.
     * @param options - Additional options for the request.
     * @returns A Promise that resolves to the Appium logs.
     */
    getSessionAppiumLogs(buildId: string, sessionId: string, options?: APIFetchOptions<operations["getAppAutomateAppiumLogs"]>): Promise<string>;
    /**
     * Retrieves the network logs for a specific session in a build.
     * @param buildId The ID of the build.
     * @param sessionId The ID of the session.
     * @param options Additional options for the network logs request.
     * @returns A Promise that resolves to the network logs response.
     */
    getSessionNetworkLogs(buildId: string, sessionId: string, options?: APIFetchOptions<operations["getAppAutomateNetworkLogs"]>): Promise<Record<string, never>>;
    /**
     * Retrieves the app profiling data for a specific session in a build.
     * @param buildId The ID of the build.
     * @param sessionId The ID of the session.
     * @param options Additional options for the request.
     * @returns A promise that resolves to the app profiling data.
     */
    getSessionAppProfilingDataV1(buildId: string, sessionId: string, options?: APIFetchOptions<operations["getAppAutomateAppProfilingDataV1"]>): Promise<{
        ts: number;
        cpu: number;
        mem: number;
        mema: number;
        batt: number;
        temp: number;
        additionalProperties?: Record<string, never> | undefined;
    }[]>;
    /**
     * Retrieves the app profiling data for a specific session in a build.
     * @param buildId The ID of the build.
     * @param sessionId The ID of the session.
     * @param options Additional options for the API request.
     * @returns A promise that resolves with the app profiling data.
     */
    getSessionAppProfilingDataV2(buildId: string, sessionId: string, options?: APIFetchOptions<operations["getAppAutomateAppProfilingDataV2"]>): Promise<{
        metadata: {
            [key: string]: unknown;
        };
        data: {
            [key: string]: unknown;
            units?: {
                [key: string]: unknown;
            } | undefined;
        };
    }>;
    /**
     * Uploads a media file to the App Automate API.
     *
     * @param body - The request body containing the media file to upload.
     * @param options - Optional fetch options for the request.
     * @returns A promise that resolves to the response of the API request.
     */
    uploadMediaFile(body: operations["uploadAppAutomateMediaFile"]["requestBody"]["content"]["multipart/form-data"] & {
        filename: string;
    }, options?: APIFetchOptions<operations["uploadAppAutomateMediaFile"]>): Promise<{
        media_id: string;
        media_url: string;
        media_name?: string | undefined;
        uploaded_at?: string | undefined;
        custom_id?: string | undefined;
        shareable_id?: string | undefined;
    }>;
    /**
     * Retrieves the media files associated with the App Automate session.
     *
     * @param options - Optional fetch options for the request.
     * @returns A promise that resolves to an array of media files, or an empty array if no media files are found.
     */
    getMediaFiles(options?: APIFetchOptions<operations["getAppAutomateMediaFiles"]>): Promise<{
        media_id: string;
        media_url: string;
        media_name?: string | undefined;
        uploaded_at?: string | undefined;
        custom_id?: string | undefined;
        shareable_id?: string | undefined;
    }[]>;
    /**
     * Retrieves media files by custom ID.
     * @param customId - The custom ID to filter media files.
     * @param options - Optional fetch options.
     * @returns A promise that resolves to an array of media files or an empty array if no media files are found.
     */
    getMediaFilesByCustomId(customId: string, options?: APIFetchOptions<operations["getAppAutomateMediaFilesByCustomId"]>): Promise<{
        media_id: string;
        media_url: string;
        media_name?: string | undefined;
        uploaded_at?: string | undefined;
        custom_id?: string | undefined;
        shareable_id?: string | undefined;
    }[]>;
    /**
     * Retrieves the group's media files from the App Automate API.
     *
     * @param options - Optional fetch options for the API request.
     * @returns A promise that resolves to an array of group media files, or an empty array if the response contains a "message" property.
     */
    getGroupMediaFiles(options?: APIFetchOptions<operations["getAppAutomateGroupMediaFiles"]>): Promise<{
        media_id: string;
        media_url: string;
        media_name?: string | undefined;
        uploaded_at?: string | undefined;
        custom_id?: string | undefined;
        shareable_id?: string | undefined;
    }[]>;
    /**
     * Deletes a media file from the app automate custom media.
     * @param mediaId The ID of the media file to delete.
     * @param options The fetch options for the delete request.
     * @returns A promise that resolves when the media file is successfully deleted.
     */
    deleteMediaFile(mediaId: string, options?: APIFetchOptions<operations["deleteAppAutomateMediaFile"]>): Promise<{
        success: boolean;
    }>;
    /**
     * Uploads an Appium app to BrowserStack App Automate.
     *
     * @param body - The request body containing the app file or URL to be uploaded.
     * @param options - Additional options for the request.
     * @returns A Promise that resolves to the response of the upload request.
     */
    uploadAppiumApp(body: operations["uploadAppAutomateApp"]["requestBody"]["content"]["multipart/form-data"] & {
        filename: string;
    }, options?: APIFetchOptions<operations["uploadAppAutomateApp"]>): Promise<{
        app_id?: string | undefined;
        app_url: string;
        app_name?: string | undefined;
        uploaded_at?: string | undefined;
        custom_id?: string | undefined;
        shareable_id?: string | undefined;
    }>;
    /**
     * Retrieves the list of Appium apps from the App Automate API.
     *
     * @param options - Optional fetch options for customizing the request.
     * @returns A promise that resolves to an array of Appium apps, or an empty array if no apps are found.
     */
    getAppiumApps(options?: APIFetchOptions<operations["getAppAutomateApps"]>): Promise<{
        app_id?: string | undefined;
        app_url: string;
        app_name?: string | undefined;
        uploaded_at?: string | undefined;
        custom_id?: string | undefined;
        shareable_id?: string | undefined;
    }[]>;
    /**
     * Retrieves the Appium apps by custom ID.
     * @param customId The custom ID of the app.
     * @param options The fetch options for the request.
     * @returns A promise that resolves to the retrieved Appium apps.
     */
    getAppiumAppsByCustomId(customId: string, options?: APIFetchOptions<operations["getAppAutomateAppsByCustomId"]>): Promise<{
        app_id?: string | undefined;
        app_url: string;
        app_name?: string | undefined;
        uploaded_at?: string | undefined;
        custom_id?: string | undefined;
        shareable_id?: string | undefined;
    }[]>;
    /**
     * Retrieves the list of App Automate apps for the group using the specified fetch options.
     * @param options The fetch options for the request.
     * @returns A promise that resolves to the list of group apps, or an empty array if there is a "message" property in the response data.
     */
    getAppiumGroupApps(options?: APIFetchOptions<operations["getAppAutomateGroupApps"]>): Promise<{
        app_id?: string | undefined;
        app_url: string;
        app_name?: string | undefined;
        uploaded_at?: string | undefined;
        custom_id?: string | undefined;
        shareable_id?: string | undefined;
    }[]>;
    /**
     * Deletes an Appium app.
     *
     * @param appId - The ID of the app to delete.
     * @param options - Optional fetch options for the delete request.
     * @returns A promise that resolves when the app is successfully deleted.
     */
    deleteAppiumApp(appId: string, options?: APIFetchOptions<operations["deleteAppAutomateApp"]>): Promise<{
        success: boolean;
    }>;
    uploadFlutterApp<P extends FlutterPlatform.ios>(platform: P, body: operations["uploadAppAutomateFlutteriOSApp"]["requestBody"]["content"]["multipart/form-data"] & {
        filename: string;
    }, options?: APIFetchOptions<operations["uploadAppAutomateFlutteriOSApp"]>): Promise<components["schemas"]["AppAutomateTestPackage"]>;
    uploadFlutterApp<P extends FlutterPlatform.android>(platform: P, body: operations["uploadAppAutomateFlutterAndroidApp"]["requestBody"]["content"]["multipart/form-data"] & {
        filename: string;
    }, options?: APIFetchOptions<operations["uploadAppAutomateFlutterAndroidApp"]>): Promise<components["schemas"]["AppAutomateApp"]>;
    getFlutterApps<P extends FlutterPlatform.android>(platform: P, options?: APIFetchOptions<operations["getAppAutomateFlutterAndroidApps"]>): Promise<components["schemas"]["AppAutomateApp"][]>;
    getFlutterApps<P extends FlutterPlatform.ios>(platform: P, options?: APIFetchOptions<operations["getAppAutomateFlutteriOSApps"]>): Promise<components["schemas"]["AppAutomateTestPackage"][]>;
    getFlutterApp<P extends FlutterPlatform.android>(platform: P, appId: string, options?: APIFetchOptions<operations["getAppAutomateFlutterAndroidApp"]>): Promise<components["schemas"]["AppAutomateApp"]>;
    getFlutterApp<P extends FlutterPlatform.ios>(platform: P, appId: string, options?: APIFetchOptions<operations["getAppAutomateFlutteriOSApp"]>): Promise<components["schemas"]["AppAutomateTestPackage"]>;
    deleteFlutterApp<P extends FlutterPlatform.android>(platform: P, appId: string, options?: APIFetchOptions<operations["deleteAppAutomateFlutterAndroidApp"]>): Promise<{
        success: {
            message: string;
        };
    }>;
    deleteFlutterApp<P extends FlutterPlatform.ios>(platform: P, appId: string, options?: APIFetchOptions<operations["deleteAppAutomateFlutteriOSApp"]>): Promise<{
        success: {
            message: string;
        };
    }>;
    /**
     * Uploads an Espresso app to BrowserStack.
     *
     * @param body - The request body containing the app file or URL.
     * @param options - Additional options for the request.
     * @returns A promise that resolves to the response from the server.
     */
    uploadEspressoApp(body: operations["uploadAppAutomateEspressoApp"]["requestBody"]["content"]["multipart/form-data"] & {
        filename: string;
    }, options?: APIFetchOptions<operations["uploadAppAutomateEspressoApp"]>): Promise<{
        app_id?: string | undefined;
        app_url: string;
        app_name?: string | undefined;
        uploaded_at?: string | undefined;
        custom_id?: string | undefined;
        shareable_id?: string | undefined;
    }>;
    /**
     * Retrieves the Espresso apps from the App Automate API.
     * @param options - The fetch options for the API request.
     * @returns A promise that resolves to an array of Espresso apps.
     */
    getEspressoApps(options?: APIFetchOptions<operations["getAppAutomateEspressoApps"]>): Promise<{
        app_id?: string | undefined;
        app_url: string;
        app_name?: string | undefined;
        uploaded_at?: string | undefined;
        custom_id?: string | undefined;
        shareable_id?: string | undefined;
    }[]>;
    /**
     * Retrieves the Espresso app with the specified appId.
     * @param appId The ID of the Espresso app to retrieve.
     * @param options The fetch options for the request.
     * @returns A promise that resolves to the retrieved Espresso app.
     */
    getEspressoApp(appId: string, options?: APIFetchOptions<operations["getAppAutomateEspressoApp"]>): Promise<{
        app_id?: string | undefined;
        app_url: string;
        app_name?: string | undefined;
        uploaded_at?: string | undefined;
        custom_id?: string | undefined;
        shareable_id?: string | undefined;
    }>;
    /**
     * Deletes an Espresso app.
     * @param appId The ID of the app to delete.
     * @param options The fetch options for the delete request.
     * @returns A promise that resolves when the app is deleted.
     */
    deleteEspressoApp(appId: string, options?: APIFetchOptions<operations["deleteAppAutomateEspressoApp"]>): Promise<{
        success: {
            message: string;
        };
    }>;
    /**
     * Uploads an XCUITest app to BrowserStack App Automate.
     *
     * @param body - The request body containing the XCUITest app file or URL.
     * @param options - Additional options for the request.
     * @returns A Promise that resolves to the response of the request.
     */
    uploadXCUITestApp(body: operations["uploadAppAutomateXCUITestApp"]["requestBody"]["content"]["multipart/form-data"] & {
        filename: string;
    }, options?: APIFetchOptions<operations["uploadAppAutomateXCUITestApp"]>): Promise<{
        app_id?: string | undefined;
        app_url: string;
        app_name?: string | undefined;
        uploaded_at?: string | undefined;
        custom_id?: string | undefined;
        shareable_id?: string | undefined;
    }>;
    /**
     * Retrieves the XCUITest apps available in the BrowserStack App Automate.
     * @param options - The fetch options for the request.
     * @returns A promise that resolves to an array of XCUITest apps.
     */
    getXCUITestApps(options?: APIFetchOptions<operations["getAppAutomateXCUITestApps"]>): Promise<{
        app_id?: string | undefined;
        app_url: string;
        app_name?: string | undefined;
        uploaded_at?: string | undefined;
        custom_id?: string | undefined;
        shareable_id?: string | undefined;
    }[]>;
    /**
     * Retrieves the XCUITest app with the specified appId.
     * @param appId The ID of the XCUITest app to retrieve.
     * @param options The fetch options for the request.
     * @returns A promise that resolves to the XCUITest app.
     */
    getXCUITestApp(appId: string, options?: APIFetchOptions<operations["getAppAutomateXCUITestApp"]>): Promise<{
        app_id?: string | undefined;
        app_url: string;
        app_name?: string | undefined;
        uploaded_at?: string | undefined;
        custom_id?: string | undefined;
        shareable_id?: string | undefined;
    }>;
    /**
     * Deletes an XCUITest app.
     * @param appId The ID of the app to delete.
     * @param options The fetch options for the delete request.
     * @returns A promise that resolves when the app is successfully deleted.
     */
    deleteXCUITestApp(appId: string, options?: APIFetchOptions<operations["deleteAppAutomateXCUITestApp"]>): Promise<{
        success: {
            message: string;
        };
    }>;
    uploadDetoxAndroidApp<T extends "app" | "app-client">(type: T, body: operations[T extends "app" ? "uploadAppAutomateDetoxAndroidApp" : "uploadAppAutomateDetoxAndroidAppClient"]["requestBody"]["content"]["multipart/form-data"] & {
        filename: string;
    }, options?: APIFetchOptions<operations[T extends "app" ? "uploadAppAutomateDetoxAndroidApp" : "uploadAppAutomateDetoxAndroidAppClient"]>): Promise<{
        app_id?: string | undefined;
        app_url: string;
        app_name?: string | undefined;
        uploaded_at?: string | undefined;
        custom_id?: string | undefined;
        shareable_id?: string | undefined;
    }>;
}
export declare enum FlutterPlatform {
    android = "android",
    ios = "ios"
}
