import { LocalTestingBinaryOptions } from './local-testing-binary-options.ts';
import { LocalTestingClient } from './local-testing.ts';
export type { LocalBinaryFlags, LocalBinaryFolderTestingFlags, LocalBinaryServerTestingFlags, LocalTestingBinaryOptions, ProxyParams, } from './local-testing-binary-options.ts';
/**
 * Represents a client for interacting with the BrowserStack Local binary and APIs.
 * Extends features of {@link LocalTestingClient} for the node.js runtime.
 * Download, spawn, and control the BrowserStack Local binary.
 * @public
 *
 * @example
 * ```ts
 * const localTesting = new BrowserStack.LocalTestingBinary({ key: "my-key" });
 * await localTesting.start();
 * console.log(localTesting.state); // "started"
 * console.log(localTesting.pid); // 12345
 * await localTesting.stop();
 * console.log(localTesting.state); // "stopped"
 * console.log(localTesting.pid); // undefined
 * ```
 */
export declare class LocalTestingBinary extends LocalTestingClient {
    private readonly options?;
    readonly localIdentifier: string;
    readonly child: {
        pid?: number;
        args: string[];
    };
    readonly commandTimeoutMs: number;
    /**
     * The last state of the BrowserStackLocal daemon command.
     * @public
     */
    state: "stopped" | "starting" | "started" | "stopping";
    /**
     * Constructs a new instance of the ScreenshotsClient class.
     * @param options - Optional configuration options for the client.
     */
    constructor(options?: LocalTestingBinaryOptions | undefined);
    /**
     * Retrieves the version of the local testing binary.
     * @returns A promise that resolves to the version string.
     */
    version(): Promise<string>;
    /**
     * Starts the BrowserStackLocal daemon.
     *
     * @returns A promise that resolves to a string if the binary starts successfully, or undefined if there is an error.
     */
    start(): Promise<string | undefined>;
    /**
     * Stops the BrowserStackLocal daemon.
     *
     * @returns A promise that resolves to a string if the daemon stops successfully, or undefined otherwise.
     */
    stop(): Promise<string | undefined>;
    /**
     * @internal
     */
    private runDaemonCommand;
    /**
     * @internal
     */
    private static resolveArgs;
    get pid(): number | undefined;
    get args(): string[];
    /**
     * @internal
     */
    private parseOutput;
    /**
     * @internal
     */
    private getBinHome;
    /**
     * @internal
     */
    private ensureBinaryExists;
}
